package org.greenstone.gsdl3.util;

/** utitility class to handle greenstone OIDs
 *
 * based around OIDtools.h from gsdl
 */
public class OID {
    
    /** returns everything up to the first dot 
	if no dot, returns OID */
    public static String getTop(String OID) {
	int pos = OID.indexOf('.');
	if (pos == -1) {
	    return OID;
	}
	return OID.substring(0, pos);
    }
    /** returns true is OID is top level (ie has no dots) */
    public static boolean isTop(String OID) {
	return (OID.indexOf('.')==-1);
    }
	
    /** returns the parent of OID (everything up to last dot) 
     returns "" if OID has no parent */
    public static String getParent(String OID) {
	int pos = OID.lastIndexOf('.');
	if (pos == -1) {
	    return "";
	}
	return OID.substring(0, pos);
    }

    /** returns the full name - replaces " with parent */
    public static String translateParent(String OID, String parent) {
	// this is the behaviour of the original - should only replace first
	//perhaps?
	return OID.replaceAll("\"", parent); 
    }
    /** does the opposite to translate_parent */
    public static String shrinkParent(String OID) {
	int pos = OID.lastIndexOf('.');
	if (pos==-1) return OID;
	return "\""+OID.substring(pos);
    }
    /** returns true if OID uses .fc, .lc, .pr, .ns, .ps */
    public static boolean needsTranslating(String OID) {
	String tail = OID.substring(OID.length()-3);
	return (tail.equals(".fc") || tail.equals(".lc") || tail.equals(".pr")
		|| tail.equals(".ns") || tail.equals(".ps"));
    }
    /** strips suffix from end */
    public static String stripSuffix(String OID) {
	String tail = OID.substring(OID.length()-3);
	while (tail.equals(".fc") || tail.equals(".lc") || tail.equals(".pr")
	       || tail.equals(".ns") || tail.equals(".ps")) {
	    OID = OID.substring(0, OID.length()-3);
	    tail = OID.substring(OID.length()-3);
	}
	return OID;
    }
    /** returns true if child is a child of parent */
    public static boolean isChildOf(String parent, String child) {
	return child.startsWith(parent);
    }
}
